@@ -1,4 +1,4 @@
-/* Copyright © 2005-2006  Roger Leigh <rleigh@debian.org>
+/* Copyright © 2005-2007  Roger Leigh <rleigh@debian.org>
  *
  * schroot is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include <sbuild/sbuild-format-detail.h>
 #include <sbuild/sbuild-keyfile.h>
 #include <sbuild/sbuild-personality.h>
+#include <sbuild/sbuild-regex.h>
 #include <sbuild/sbuild-tr1types.h>
 
 #include <ostream>
@@ -321,6 +322,26 @@ namespace sbuild
     void
     set_aliases (string_list const& aliases);
 
+    /**
+     * Get the environment filter of the chroot.  This is a POSIX
+     * extended regular expression used to remove insecure environment
+     * variables from the chroot environment.
+     *
+     * @returns the filter
+     */
+    regex const&
+    get_environment_filter () const;
+
+    /**
+     * Get the environment filter of the chroot.  This is a POSIX
+     * extended regular expression used to remove insecure environment
+     * variables from the chroot environment.
+     *
+     * @param environment_filter the filter.
+     */
+    void
+    set_environment_filter (regex const& environment_filter);
+
     /**
      * Get the activity status of the chroot.
      *
@@ -387,6 +408,26 @@ namespace sbuild
     void
     set_run_exec_scripts (bool run_exec_scripts);
 
+    /**
+     * Get the script configuration file for the chroot.  This is a
+     * filename, either relative to the configured pkgsysconfdir or an
+     * absolute path.
+     *
+     * @returns the configuration file name.
+     */
+    std::string const&
+    get_script_config () const;
+
+    /**
+     * Set the script configuration file for the chroot.  This is a
+     * filename, either relative to the configured pkgsysconfdir or an
+     * absolute path.
+     *
+     * @param script_config the script configuration file.
+     */
+    void
+    set_script_config (std::string const& script_config);
+
     /**
      * Get the command_prefix for the chroot.  This is a command to
      * prefix to any command run in the chroot.
@@ -605,6 +646,8 @@ namespace sbuild
     string_list   root_groups;
     /// Alternative names for the chroot.
     string_list   aliases;
+    /// Environment filter regex.
+    regex         environment_filter;
     /// Location to mount chroot in the filesystem (if any).
     std::string   mount_location;
     /// Location inside the mount location root.
@@ -619,6 +662,8 @@ namespace sbuild
     bool          run_setup_scripts;
     /// Run chroot exec scripts?
     bool          run_exec_scripts;
+    /// Configuration of the setup and exec scripts.
+    std::string   script_config;
     /// Command prefix.
     string_list   command_prefix;
     /// Process execution domain (Linux only).
