@@ -1,4 +1,4 @@
-/* Copyright © 2005-2006  Roger Leigh <rleigh@debian.org>
+/* Copyright © 2005-2007  Roger Leigh <rleigh@debian.org>
  *
  * schroot is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 
 #include "sbuild-chroot-plain.h"
 #include "sbuild-chroot-lvm-snapshot.h"
+#include "sbuild-ctty.h"
 #include "sbuild-run-parts.h"
 #include "sbuild-session.h"
 #include "sbuild-util.h"
@@ -42,7 +43,11 @@
 
 #include <boost/format.hpp>
 
+#ifdef HAVE_UUID
 #include <uuid/uuid.h>
+#else
+#include <time.h>
+#endif
 
 using std::cout;
 using std::endl;
@@ -98,6 +103,9 @@ namespace
       emap(session::GROUP_UNKNOWN,  N_("Group '%1%' not found")),
       emap(session::PAM,            N_("PAM error")),
       emap(session::ROOT_DROP,      N_("Failed to drop root permissions")),
+      // TRANSLATORS: %1% = chroot name
+      // TRANSLATORS: %4% = session identifier
+      emap(session::SET_SESSION_ID, N_("%1%: Chroot does not support setting a session ID; ignoring session ID '%4%'")),
       // TRANSLATORS: %1% = command
       emap(session::SHELL,          N_("Shell '%1%' not available")),
       // TRANSLATORS: %4% = command
@@ -237,6 +245,7 @@ session::session (std::string const&         service,
   config(config),
   chroots(chroots),
   chroot_status(true),
+  lock_status(true),
   child_status(0),
   session_operation(operation),
   session_id(),
@@ -316,16 +325,15 @@ session::set_force (bool force)
 void
 session::save_termios ()
 {
-  int ctty = open("/dev/tty", O_RDONLY|O_NOCTTY);
   string_list const& command(auth::get_command());
 
   this->termios_ok = false;
 
   // Save if running a login shell and have a controlling terminal.
-  if (ctty >= 0 &&
+  if (CTTY_FILENO >= 0 &&
       (command.empty() || command[0].empty()))
     {
-      if (tcgetattr(ctty, &this->saved_termios) < 0)
+      if (tcgetattr(CTTY_FILENO, &this->saved_termios) < 0)
 	{
 	  sbuild::log_warning()
 	    << _("Error saving terminal settings")
@@ -334,31 +342,24 @@ session::save_termios ()
       else
 	this->termios_ok = true;
     }
-
-  if (ctty >= 0 && close(ctty))
-    log_debug(DEBUG_WARNING) << "Failed to close CTTY fd " << ctty << endl;
 }
 
 void
 session::restore_termios ()
 {
-  int ctty = open("/dev/tty", O_WRONLY|O_NOCTTY);
   string_list const& command(auth::get_command());
 
   // Restore if running a login shell and have a controlling terminal,
   // and have previously saved the terminal state.
-  if (ctty >= 0 &&
+  if (CTTY_FILENO >= 0 &&
       (command.empty() || command[0].empty()) &&
       termios_ok)
     {
-      if (tcsetattr(ctty, TCSANOW, &this->saved_termios) < 0)
+      if (tcsetattr(CTTY_FILENO, TCSANOW, &this->saved_termios) < 0)
 	sbuild::log_warning()
 	  << _("Error restoring terminal settings")
 	  << endl;
     }
-
-  if (ctty >= 0 && close(ctty))
-    log_debug(DEBUG_WARNING) << "Failed to close CTTY fd " << ctty << endl;
 }
 
 int
@@ -463,8 +464,9 @@ session::get_auth_status () const
 
   auth::status status = auth::STATUS_NONE;
 
-  /* @todo Use set difference rather than iteration and
-     is_group_member. */
+  /** @todo Use set difference rather than iteration and
+   * is_group_member.
+   */
   for (string_list::const_iterator cur = this->chroots.begin();
        cur != this->chroots.end();
        ++cur)
@@ -517,17 +519,37 @@ session::run_impl ()
 	  if (chroot->get_active() ||
 	      !(chroot->get_session_flags() & chroot::SESSION_CREATE))
 	    {
+	      if (!get_session_id().empty())
+		{
+		  session::error e(chroot->get_name(),
+				   session::SET_SESSION_ID,
+				   get_session_id());
+		  log_exception_warning(e);
+		}
+
 	      set_session_id(chroot->get_name());
 	    }
 	  else
 	    {
-	      uuid_t uuid;
-	      char uuid_str[37];
-	      uuid_generate(uuid);
-	      uuid_unparse(uuid, uuid_str);
-	      uuid_clear(uuid);
-	      std::string session_id(chroot->get_name() + "-" + uuid_str);
-	      set_session_id(session_id);
+	      if (get_session_id().empty())
+		{
+#ifdef HAVE_UUID
+		  uuid_t uuid;
+		  char uuid_str[37];
+		  uuid_generate(uuid);
+		  uuid_unparse(uuid, uuid_str);
+		  uuid_clear(uuid);
+		  std::string session_id(chroot->get_name() + '-' + uuid_str);
+		  set_session_id(session_id);
+#else
+		  std::ostringstream session_id;
+		  session_id.imbue(std::locale::classic());
+		  session_id << chroot->get_name()
+			     << '-' << isodate(time(0))
+			     << '-' << getpid();
+		  set_session_id(session_id.str());
+#endif
+		}
 	    }
 
 	  log_debug(DEBUG_INFO)
@@ -880,6 +902,10 @@ session::setup_chroot (sbuild::chroot::ptr&       session_chroot,
 {
   assert(!session_chroot->get_name().empty());
 
+  log_debug(DEBUG_INFO) << format("setup_chroot: chroot=%1%, setup_type=%2%, chroot_status=%3%, lock_status=%4%")
+    % session_chroot->get_name() % setup_type % chroot_status % lock_status
+			<< std::endl;
+
   if (!((this->session_operation == OPERATION_BEGIN &&
 	 setup_type == chroot::SETUP_START) ||
 	(this->session_operation == OPERATION_RECOVER &&
@@ -896,6 +922,10 @@ session::setup_chroot (sbuild::chroot::ptr&       session_chroot,
 	  setup_type == chroot::EXEC_STOP))))
     return;
 
+  // Don't clean up chroot on a lock failure--it's actually in use.
+  if (this->lock_status == false)
+    return;
+
   if (((setup_type == chroot::SETUP_START   ||
 	setup_type == chroot::SETUP_RECOVER ||
 	setup_type == chroot::SETUP_STOP) &&
@@ -915,6 +945,7 @@ session::setup_chroot (sbuild::chroot::ptr&       session_chroot,
   catch (chroot::error const& e)
     {
       this->chroot_status = false;
+      this->lock_status = false;
       try
 	{
 	  // Release lock, which also removes session metadata.
@@ -1044,6 +1075,7 @@ session::setup_chroot (sbuild::chroot::ptr&       session_chroot,
   catch (chroot::error const& e)
     {
       this->chroot_status = false;
+      this->lock_status = false;
       throw error(session_chroot->get_name(), CHROOT_UNLOCK, e);
     }
 
@@ -1150,7 +1182,20 @@ session::run_child (sbuild::chroot::ptr& session_chroot)
 			  << std::endl;
 
   /* Set up environment */
-  environment env = get_pam_environment();
+  environment env;
+  env.set_filter(session_chroot->get_environment_filter());
+  env += get_pam_environment();
+
+  // Add equivalents to sudo's SUDO_USER, SUDO_UID, SUDO_GID, and
+  // SUDO_COMMAND.
+  env.add(std::make_pair("SCHROOT_COMMAND",
+			 string_list_to_string(command, " ")));
+  env.add(std::make_pair("SCHROOT_USER", get_ruser()));
+  env.add(std::make_pair("SCHROOT_GROUP", get_rgroup()));
+  env.add("SCHROOT_UID", get_ruid());
+  env.add("SCHROOT_GID", get_rgid());
+
+
   log_debug(DEBUG_INFO) << "Set environment:\n" << env;
 
   // The user's command does not use our syslog fd.
@@ -1204,7 +1249,7 @@ session::wait_for_child (pid_t pid,
 	  child_killed = true;
 	}
 
-      if (wait(&status) != pid)
+      if (waitpid(pid, &status, 0) == -1)
 	{
 	  if (errno == EINTR && (sighup_called || sigterm_called))
 	    continue; // Kill child and wait again.
