@@ -1,4 +1,4 @@
-/* Copyright © 2006  Roger Leigh <rleigh@debian.org>
+/* Copyright © 2006-2007  Roger Leigh <rleigh@debian.org>
  *
  * schroot is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 using namespace sbuild;
 
 const char *
-sbuild::date_base::get_date_format ()
+sbuild::date_base::get_date_format () const
 {
   // TRANSLATORS: Format string for date representation:
   // %d = day (number, e.g. 14)
@@ -37,3 +37,9 @@ sbuild::date_base::get_date_format ()
   // the equivalent standard method for your locale.
   return _("%d %b %Y");
 }
+
+const char *
+sbuild::isodate::get_date_format () const
+{
+  return "%Y-%m-%dT%H:%M:%SZ";
+}
