@@ -1,4 +1,4 @@
-/* Copyright © 2006  Roger Leigh <rleigh@debian.org>
+/* Copyright © 2006-2007  Roger Leigh <rleigh@debian.org>
  *
  * schroot is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -17,6 +17,8 @@
  *
  *********************************************************************/
 
+#include <config.h>
+
 #include <sbuild/sbuild-chroot-file.h>
 
 #include "test-helpers.h"
@@ -88,6 +90,7 @@ public:
     expected.add("CHROOT_MOUNT_LOCATION", "/mnt/mount-location");
     expected.add("CHROOT_PATH",           "/mnt/mount-location");
     expected.add("CHROOT_MOUNT_DEVICE",   "/dev/device-to-mount");
+    expected.add("CHROOT_SCRIPT_CONFIG",  sbuild::normalname(std::string(PACKAGE_SYSCONF_DIR) + "/script-defaults"));
 
     test_chroot_base<chroot_file>::test_setup_env(expected);
   }
