@@ -1,4 +1,4 @@
-/* Copyright © 2006  Roger Leigh <rleigh@debian.org>
+/* Copyright © 2006-2007  Roger Leigh <rleigh@debian.org>
  *
  * schroot is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -17,6 +17,8 @@
  *
  *********************************************************************/
 
+#include <config.h>
+
 #include <sbuild/sbuild-chroot.h>
 
 #include "test-helpers.h"
@@ -78,6 +80,7 @@ class test_chroot : public test_chroot_base<basic_chroot>
   CPPUNIT_TEST(test_groups);
   CPPUNIT_TEST(test_root_groups);
   CPPUNIT_TEST(test_aliases);
+  CPPUNIT_TEST(test_environment_filter);
   CPPUNIT_TEST(test_active);
   CPPUNIT_TEST(test_run_setup_scripts);
   CPPUNIT_TEST(test_run_exec_scripts);
@@ -164,6 +167,15 @@ public:
 	      &sbuild::chroot::set_aliases);
   }
 
+  void test_environment_filter()
+  {
+    sbuild::regex r("foo|bar|baz");
+
+    chroot->set_environment_filter(r);
+
+    CPPUNIT_ASSERT(chroot->get_environment_filter().compare(r) == 0);
+  }
+
   void test_active()
   {
     CPPUNIT_ASSERT(chroot->get_active() == false);
@@ -205,6 +217,7 @@ public:
     expected.add("CHROOT_MOUNT_LOCATION", "/mnt/mount-location");
     expected.add("CHROOT_PATH",           "/mnt/mount-location");
     expected.add("CHROOT_MOUNT_DEVICE",   "/dev/device-to-mount");
+    expected.add("CHROOT_SCRIPT_CONFIG",  sbuild::normalname(std::string(PACKAGE_SYSCONF_DIR) + "/script-defaults"));
 
     test_chroot_base<basic_chroot>::test_setup_env(expected);
   }
